@@ -61,7 +61,7 @@ def check_permissions_folder():
 			except:
 				print("\n=> Error - your operating system user does not have permission to write to file path:\n" + app_dir + "\n")
 				print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
-				raise
+				return False
 
 			if write_response != 0:
 				print("\n=> Error - your operating system user does not have permission to write to file path:\n" + app_dir + "\n")
@@ -74,14 +74,14 @@ def check_permissions_folder():
 				except:
 					print("\n=> Error - your operating system user does not have permission to read from file path:\n" + app_dir + "\n")
 					print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
-					raise
+					return False
 
 				if read_response != 0:
 					print("\n=> Error - your operating system user does not have permission to read from file path:\n" + app_dir + "\n")
 					print("\n=> Fix - you can attempt to fix this by running `pds.grant_permissions_folder()`.\n")
 					return False
 				else:
-					cmd_file_delete = "erase " + app_dir + file_name + " -Y"
+					cmd_file_delete = "erase " + app_dir + file_name
 					os.system(cmd_file_delete)
 					print("\n=> Success - your operating system user can read from and write to file path:\n" + app_dir + "\n")
 
@@ -107,28 +107,31 @@ def check_permissions_folder():
 
 
 def grant_permissions_folder():
-	# Originally, I was checking permissions and only proceeding if they weren't already set...
-	# ...but this is a showstopper so I always want this to run.
-	try:
-		if os.name == 'nt':
-			# Windows ICACLS permissions: https://www.educative.io/edpresso/what-is-chmod-in-windows
-			# Works in Windows Command Prompt and `os.system()`, but not PowerShell.
-			command = 'icacls "' + app_dir + '" /grant users:(F) /t /c'
-			sys_response = os.system(command)
-		else:
-			# posix
-			command = 'chmod +wr ' + '"' + app_dir + '"'
-			sys_response = os.system(command)
-	except:
-		print("\n=> Error - error failed to execute this system command:\n" + command)
-		print("===================================\n")
-		raise
-	
 	permissions = check_permissions_folder()
 	if permissions:
-		print("\n=> Success - granted system permissions to read and write from file path:\n" + app_dir + "\n")
+		print("\n=> Warning - skipping as you already have permissions to read from and write to file path:\n" + app_dir + "\n")
 	else:
-		print("\n=> Error - failed to grant system permissions to read and write from file path:\n" + app_dir + "\n")
+		try:
+			if os.name == 'nt':
+				# Windows ICACLS permissions: https://www.educative.io/edpresso/what-is-chmod-in-windows
+				# Works in Windows Command Prompt and `os.system()`, but not PowerShell.
+				# Does not work with trailing backslashes \\
+				command = 'icacls "' + app_dir_free + '" /grant users:(F) /t /c'
+				os.system(command)
+			else:
+				# posix
+				command = 'chmod +wr ' + '"' + app_dir + '"'
+				os.system(command)
+		except:
+			print("\n=> Error - error failed to execute this system command:\n" + command)
+			print("===================================\n")
+			raise
+		
+		permissions = check_permissions_folder()
+		if permissions:
+			print("\n=> Success - granted system permissions to read and write from file path:\n" + app_dir + "\n")
+		else:
+			print("\n=> Error - failed to grant system permissions to read and write from file path:\n" + app_dir + "\n")
 
 
 def get_config():
